/*
 * Copyright 2005-2007 Freescale Semiconductor, Inc. All Rights Reserved.
 */

/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*=============================================================================
                                                                               
    Module Name:            mfw_gst_aacplusdec.h

    General Description:    Gstreamer plugin for AACPLUS decoder
    
===============================================================================
Portability: This file is ported for Linux and GStreamer.

===============================================================================
                            INCLUDE FILES
=============================================================================*/

#ifndef __MFW_GST_AACPLUSDEC_H__
#define __MFW_GST_AACPLUSDEC_H__

/*=============================================================================
                                           CONSTANTS
=============================================================================*/

/* None. */

/*=============================================================================
                                             ENUMS
=============================================================================*/

/* None. */

/*=============================================================================
                                            MACROS
=============================================================================*/
G_BEGIN_DECLS
#define MFW_GST_TYPE_AACPLUSDEC \
  (mfw_gst_aacplusdec_get_type())
#define MFW_GST_AACPLUSDEC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),MFW_GST_TYPE_AACPLUSDEC,\
   MFW_GST_AACPLUSDEC_INFO_T))
#define MFW_GST_AACPLUSDEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),MFW_GST_TYPE_AACPLUSDEC,MFW_GST_AACPLUSDEC_CLASS_T))
#define MFW_GST_IS_AACPLUSDEC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),MFW_GST_TYPE_AACPLUSDEC))
#define MFW_GST_IS_AACPLUSDEC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),MFW_GST_TYPE_AACPLUSDEC))
/*=============================================================================
                                 STRUCTURES AND OTHER TYPEDEFS
=============================================================================*/
    typedef struct AACPD_App_params_S {
    BitstreamParam bs_param;	/* bitstream parameters */
    AACPD_Block_Params BlockParams;	/* frame parameters */
    gint BitsInHeader;		/* number of bits used to decode the 
				   header */
    gboolean App_adif_header_present;
    /* flag to check if the header present 
       is ADIF */
    gboolean App_adts_header_present;
    /* flag to check if the header present 
       is ADTS */
    AACD_global_struct *ptr;	/* global pointer used by the decoder */
    AACPD_Decoder_Config *dec_config;	/* decoder context */
} AACPD_App_params;


typedef struct MFW_GST_AACPLUSDEC_INFO_S {
    GstElement element;
    GstPad *sinkpad;
    GstPad *srcpad;
    gboolean init_done;		/* flag to check whether the initialisation 
				   is done or not */
    GstBuffer *inbuffer1;	/* input buffer */
    GstBuffer *inbuffer2;	/* addition input buffer used for the  
				   call back */
    gboolean caps_set;		/* flag to check whether the source pad 
				   capabilities  are set or not */
    AACPD_App_params app_params;	/* parameters of the decoder used by 
					   the plugin */
    gboolean eos;		/* flag to update end of stream staus */
    gboolean seek_flag;		/* flag to check whether seek is in demuxer or in decoder  */
    gboolean flow_error;        /* flag to indicate fatal flow error happened */
    guint64 time_offset;		/* time increment of the output to 
				   update the time stamp */
    guint64 sampling_freq;
    gint bit_rate;
    guint32 number_of_channels;
    guint64 total_frames;
    gint64 total_time;
    gint bitsPerFrame;
    gint nBitsReceive;
    guint SampFreqIdx;
    gint nFramesReceived;
    gint bitstream_count;
    gint bitstream_buf_index;
    gint in_buf_done;
    gint nBitsReceived;
    guint64 buffer_time;
    gboolean corrupt_bs;
} MFW_GST_AACPLUSDEC_INFO_T;


typedef struct MFW_GST_AACPLUSDEC_CLASS_S {
    GstElementClass parent_class;
} MFW_GST_AACPLUSDEC_CLASS_T;

/*=============================================================================
                                 GLOBAL VARIABLE DECLARATIONS
=============================================================================*/

/* None. */

/*=============================================================================
                                     FUNCTION PROTOTYPES
=============================================================================*/

GType mfw_gst_aacplusdec_get_type(void);

G_END_DECLS
/*===========================================================================*/
#endif				/* __MFW_GST_AACPLUSDEC_H__ */
